{% load i18n %}
<head>
    <style>
        /* Force 2-column settings tables to align */
        .table.settings,
        .table.settings thead th,
        .table.settings tbody td {
            width: 50%;
        }

        /* Ensure fixed layout so widths are respected */
        .table.settings {
            table-layout: fixed;
        }

        /* Optional: prevent long text from breaking layout */
        .table.settings td {
            word-wrap: break-word;
        }
    </style>
</head>
<ul class="nav nav-pills mb-4">
  <li class="nav-item">
    <a
      class="nav-link{% if request.resolver_match.url_name == 'manual_settings' or request.resolver_match.url_name == 'manual_settings_bb' %} active{% endif %}"
      href="{% url 'aa_bb:manual_settings' %}"
    >{% translate "BigBrotherConfig" %}</a>
  </li>
  <li class="nav-item">
    <a
      class="nav-link{% if request.resolver_match.url_name == 'manual_settings_paps' %} active{% endif %}"
      href="{% url 'aa_bb:manual_settings_paps' %}"
    >{% translate "PapsConfig" %}</a>
  </li>
  <li class="nav-item">
    <a
      class="nav-link{% if request.resolver_match.url_name == 'manual_settings_tickets' %} active{% endif %}"
      href="{% url 'aa_bb:manual_settings_tickets' %}"
    >{% translate "TicketToolConfig" %}</a>
  </li>
  <li class="nav-item">
    <a
      class="nav-link{% if request.resolver_match.url_name == 'manual_settings_stats' %} active{% endif %}"
      href="{% url 'aa_bb:manual_settings_stats' %}"
    >{% translate "RecurringStatsConfig" %}</a>
  </li>
</ul>
