<!--
  Base layout for the Big Brother manual/FAQ section with its own nav menu.
-->
{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}

{% block page_title %}
    {% translate "BigBrother Manual" %}
{% endblock %}

{% block header_nav_collapse_left %}
    {% include 'faq/menu.html' %}
{% endblock %}

{% block content %}
    <div class="bb-manual">
        {% block details %}{% endblock %}
    </div>
{% endblock %}
