# Generated by Django 4.2.23 on 2025-08-28 09:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0070_remove_tickettoolconfig_role_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='Role_ID',
            field=models.PositiveBigIntegerField(blank=True, default=0, help_text='Role ID to get pinged alongside the non compliant user', null=True),
        ),
    ]
