# Generated by Django 4.2.23 on 2025-11-24 16:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0083_alter_bigbrotherredditmessage_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='consider_all_structures_hostile',
            field=models.BooleanField(default=False, help_text="Consider all player owned structures that are not listed as 'whitelist, ignored or member' as hostile?"),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='consider_npc_stations_hostile',
            field=models.BooleanField(default=False, help_text='Consider assets in any non-player owned (NPC) station as hostile?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='consider_nullsec_hostile',
            field=models.BooleanField(default=False, help_text='Consider all nullsec regions as hostile?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='excluded_stations',
            field=models.TextField(blank=True, help_text="List of station/structure IDs excluded from hostile checks, separated by ','", null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='excluded_systems',
            field=models.TextField(blank=True, help_text="List of system IDs excluded from hostile checks, separated by ','", null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='hostile_assets_ships_only',
            field=models.BooleanField(default=False, help_text='Only consider ship assets when checking and rendering hostile asset locations?'),
        ),
    ]
