# Generated by Django 4.2.21 on 2025-08-03 13:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0021_alter_messages_id_alter_messages_text'),
    ]

    operations = [
        migrations.AddField(
            model_name='messages',
            name='sent_in_cycle',
            field=models.BooleanField(default=False),
        ),
    ]
