# Generated by Django 4.2.23 on 2025-08-12 17:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0039_alter_bigbrotherconfig_ignored_corporations'),
    ]

    operations = [
        migrations.CreateModel(
            name='SovereigntyMapCache',
            fields=[
                ('id', models.PositiveSmallIntegerField(default=1, primary_key=True, serialize=False)),
                ('data', models.JSONField()),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'db_table': 'sovereignty_map_cache',
            },
        ),
        migrations.CreateModel(
            name='CorporationInfoCache',
            fields=[
                ('corp_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('member_count', models.IntegerField(default=0)),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'db_table': 'corporation_info_cache',
                'indexes': [models.Index(fields=['updated'], name='corporation_updated_0654f8_idx')],
            },
        ),
        migrations.CreateModel(
            name='AllianceHistoryCache',
            fields=[
                ('corp_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('history', models.JSONField()),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'db_table': 'alliance_history_cache',
                'indexes': [models.Index(fields=['updated'], name='alliance_hi_updated_df5e96_idx')],
            },
        ),
    ]
