<!--
  Splash page presented when Big Brother itself is disabled.
  Keeps the standard layout but replaces the card grid with a single alert.
-->
{% extends 'aa_bb/base.html' %}
{% load i18n %}
{% load humanize %}

{% block details %}

<!-- Error / Info Message -->
<div id="messageBox" class="alert alert-danger">
    Big Brother is currently in an inactive state, please make sure it is up to date, you have filled the settings and turned on the task.
    </div>

{% endblock %}

{% block extra_javascript %}

{% endblock %}
