# Generated by Django 4.2.23 on 2025-08-08 09:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0032_alter_leaverequest_status'),
    ]

    operations = [
        migrations.CreateModel(
            name='MessageType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50, unique=True)),
            ],
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='pingroleID2',
            field=models.CharField(default=0, help_text='Input the 2nd role ID you want pinged when people need to investigate', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='everyone_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping @everyone', related_name='everyone_configs', to='aa_bb.messagetype'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='here_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping @here', related_name='here_configs', to='aa_bb.messagetype'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='pingrole1_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping the pingrole1', related_name='pingrole1_configs', to='aa_bb.messagetype'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='pingrole2_messages',
            field=models.ManyToManyField(blank=True, help_text='List of message types that should ping the pingrole2', related_name='pingrole2_configs', to='aa_bb.messagetype'),
        ),
    ]
