# Generated by Django 4.2.20 on 2025-04-23 22:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0006_alter_bigbrotherconfig_pingroleid'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access this app'), ('full_access', 'Can view all main characters'), ('recruiter_access', 'Can view guest main characters only'), ('can_blacklist_characters', 'Can add characters to blacklist'))},
        ),
    ]
