# Generated by Django 4.2.23 on 2025-08-26 09:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0019_adding_restricted_to_groups'),
        ('aa_bb', '0059_alter_papsconfig_excluded_groups_get_paps'),
    ]

    operations = [
        migrations.AddField(
            model_name='papsconfig',
            name='cap_group',
            field=models.ManyToManyField(blank=True, help_text='Select your cap group', related_name='cap_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='cap_group_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs to add for being in the cap group'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='capital_groups_get_paps',
            field=models.BooleanField(default=False, help_text='Does being in corp capital groups give out paps?'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='super_group',
            field=models.ManyToManyField(blank=True, help_text='Select your super group', related_name='super_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='super_group_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs to add for being in the super group'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='titan_group',
            field=models.ManyToManyField(blank=True, help_text='Select your titan group', related_name='titan_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='titan_group_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs to add for being in the titan group'),
        ),
    ]
