# Generated by Django 4.2.23 on 2025-11-25 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0084_bigbrotherconfig_consider_all_structures_hostile_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='awox_notify',
            field=models.BooleanField(default=True, help_text='Whether to send AWOX notificaitons to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='ct_notify',
            field=models.BooleanField(default=True, help_text='Whether to send CT audit completion notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='ticket_notify_auto',
            field=models.BooleanField(default=True, help_text='Whether to send ticket resolution notifications when automatically closed to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='ticket_notify_man',
            field=models.BooleanField(default=True, help_text='Whether to send ticket resolution notifications when manually closed to discord'),
        ),
    ]
