# Generated by Django 4.2.23 on 2025-08-20 11:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0053_alter_papsconfig_corp_modifier_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access Big Brother'), ('full_access', 'Can view all main characters in Big Brother'), ('recruiter_access', 'Can view main characters in Guest state only in Big Brother'), ('basic_access_cb', 'Can access Corp Brother'), ('full_access_cb', 'Can view all corps in Corp Brother'), ('recruiter_access_cb', "Can view guest's corps only in Corp Brother"), ('can_blacklist_characters', 'Can add characters to blacklist'), ('can_access_loa', 'Can access and submit a Leave Of Absence request'), ('can_view_all_loa', 'Can view all Leave Of Absence requests'), ('can_manage_loa', 'Can manage Leave Of Absence requests'), ('can_access_paps', 'Can access PAP Stats'), ('can_generate_paps', 'Can generate PAP Stats'))},
        ),
    ]
