# Generated by Django 4.2.23 on 2025-08-20 11:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0052_papsconfig_delete_monthlypapstats'),
    ]

    operations = [
        migrations.AlterField(
            model_name='papsconfig',
            name='corp_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs is a corp PAP worth?'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='imp_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs is an imp PAP worth?'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='lawn_modifier',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs is a lawn PAP worth?'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='max_corp_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many Corp PAPs will count?'),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='required_paps',
            field=models.PositiveIntegerField(default=1, help_text='How many PAPs per month should a user get?'),
        ),
    ]
