# Generated by Django 4.2.23 on 2025-12-18 17:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0091_remove_bigbrotherconfig_dlc_are_recurring_stats_active_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstatus',
            name='baseline_initialized',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='characteraccountstate',
            name='last_total_sp',
            field=models.BigIntegerField(null=True, blank=True),
        ),
        migrations.AddField(
            model_name='characteraccountstate',
            name='last_checked_at',
            field=models.DateTimeField(null=True, blank=True),
        ),
    ]
