# Generated by Django 4.2.23 on 2025-08-27 13:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0068_tickettoolconfig_category_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='ticket_counter',
            field=models.PositiveIntegerField(default=0, editable=False, help_text='Rolling counter for ticket channel names'),
        ),
    ]
