{# templates/loa/_loa_subtabs.html
   Secondary nav used within the LOA interface to switch between the member
   listing and the admin review panel while preserving active state. #}
<ul class="nav nav-pills mb-4">
  <li class="nav-item">
    <a
      class="nav-link {% if request.resolver_match.url_name == 'index' %}active{% endif %}"
      href="{% url 'loa:index' %}"
    >Leave of Absence</a>
  </li>
  <li class="nav-item">
    <a
      class="nav-link {% if request.resolver_match.url_name == 'admin' %}active{% endif %}"
      href="{% url 'loa:admin' %}"
    >LoA Admin</a>
  </li>
</ul>
