<!--
  Message rendered when PAP stats are globally disabled to avoid confusing users.
-->
{% extends 'aa_bb/base.html' %}
{% load i18n %}
{% load humanize %}

{% block details %}

<!-- Error / Info Message -->
<div id="messageBox" class="alert alert-danger">
    Pap Stats are currently inactive.
    </div>

{% endblock %}

{% block extra_javascript %}

{% endblock %}
