# Generated by Django 4.2.20 on 2025-04-24 12:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0007_alter_general_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='Alliance_names',
            fields=[
                ('id', models.BigIntegerField(help_text='EVE Alliance or Faction ID', primary_key=True, serialize=False)),
                ('name', models.CharField(help_text='Resolved alliance/faction name', max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True, help_text='When this record was first saved')),
                ('updated', models.DateTimeField(auto_now=True, help_text='When this record was last refreshed')),
            ],
            options={
                'verbose_name': 'Alliance Name',
                'verbose_name_plural': 'Alliance Names',
                'db_table': 'aa_bb_alliances',
            },
        ),
        migrations.CreateModel(
            name='Corporation_names',
            fields=[
                ('id', models.BigIntegerField(help_text='EVE Corporation ID', primary_key=True, serialize=False)),
                ('name', models.CharField(help_text='Resolved corporation name', max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True, help_text='When this record was first saved')),
                ('updated', models.DateTimeField(auto_now=True, help_text='When this record was last refreshed')),
            ],
            options={
                'verbose_name': 'Corporation Name',
                'verbose_name_plural': 'Corporation Names',
                'db_table': 'aa_bb_corporations',
            },
        ),
    ]
