# Generated by Django 4.2.21 on 2025-12-10 15:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0087_bigbrotherconfig_dlc_are_recurring_stats_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='cyno_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Cyno change notifications to discord'),
        ),
    ]
