# Generated by Django 4.2.23 on 2025-08-04 07:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0022_messages_sent_in_cycle'),
    ]

    operations = [
        migrations.CreateModel(
            name='OptMessages1',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(max_length=2000)),
                ('sent_in_cycle', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='OptMessages2',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(max_length=2000)),
                ('sent_in_cycle', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='OptMessages3',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(max_length=2000)),
                ('sent_in_cycle', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='OptMessages4',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(max_length=2000)),
                ('sent_in_cycle', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='OptMessages5',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(max_length=2000)),
                ('sent_in_cycle', models.BooleanField(default=False)),
            ],
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='are_opt_messages1_active',
            field=models.BooleanField(default=False, help_text='are optional messages 1 activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='are_opt_messages2_active',
            field=models.BooleanField(default=False, help_text='are optional messages 2 activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='are_opt_messages3_active',
            field=models.BooleanField(default=False, help_text='are optional messages 3 activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='are_opt_messages4_active',
            field=models.BooleanField(default=False, help_text='are optional messages 4 activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='are_opt_messages5_active',
            field=models.BooleanField(default=False, help_text='are optional messages 5 activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optwebhook1',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 1', null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optwebhook2',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 2', null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optwebhook3',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 3', null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optwebhook4',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 4', null=True),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optwebhook5',
            field=models.URLField(blank=True, help_text='Discord webhook for sending optional messages 5', null=True),
        ),
    ]
