# Generated by Django 4.2.23 on 2025-08-20 13:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0019_adding_restricted_to_groups'),
        ('aa_bb', '0055_papsconfig_group_paps_papsconfig_group_paps_modifier'),
    ]

    operations = [
        migrations.AlterField(
            model_name='papsconfig',
            name='group_paps',
            field=models.ManyToManyField(blank=True, help_text='List of groups which give paps', related_name='bb_guest_states_configs', to='groupmanagement.authgroup'),
        ),
    ]
