# Generated by Django 4.2.23 on 2025-08-05 10:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0027_alter_general_options_bigbrotherconfig_is_loa_active_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_loa_active',
            field=models.BooleanField(default=False, help_text='has the Leave of Absence module been activated/deactivated? (You will need to restart AA for this to take effect)'),
        ),
    ]
