# Generated by Django 4.2.23 on 2025-08-06 10:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0031_bigbrotherconfig_loa_max_logoff_days_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leaverequest',
            name='status',
            field=models.CharField(choices=[('pending', 'Pending'), ('approved', 'Approved'), ('in_progress', 'In Progress'), ('finished', 'Finished'), ('denied', 'Denied')], default='pending', max_length=20),
        ),
    ]
