# Generated by Django 4.2.23 on 2025-10-19 03:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0074_alter_bigbrotherconfig_hostile_alliances'),
    ]

    operations = [
        migrations.CreateModel(
            name='BBUpdateState',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('update_check_time', models.DateTimeField(blank=True, null=True)),
                ('latest_version', models.CharField(blank=True, max_length=50, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='afk_check_frequency',
            field=models.PositiveIntegerField(default=1, help_text='How often should a user be reminded (in days)'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='corp_check_frequency',
            field=models.PositiveIntegerField(default=1, help_text='How often should a user be reminded (in days)'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_check_frequency',
            field=models.PositiveIntegerField(default=1, help_text='How often should a user be reminded (in days)'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='lawn_check_frequency',
            field=models.PositiveIntegerField(default=1, help_text='How often should a user be reminded (in days)'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='paps_check_frequency',
            field=models.PositiveIntegerField(default=1, help_text='How often should a user be reminded (in days)'),
        ),
    ]
