# Generated by Django 4.2.20 on 2025-04-26 02:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0009_userstatus_sus_contacts_userstatus_sus_contracts_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userstatus',
            name='awox_kill_links',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='userstatus',
            name='hostile_assets',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='userstatus',
            name='hostile_clones',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='userstatus',
            name='sus_contacts',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='userstatus',
            name='sus_contracts',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='userstatus',
            name='sus_mails',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='userstatus',
            name='sus_trans',
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
