# Generated by Django 4.2.23 on 2025-11-25 19:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0086_bigbrotherconfig_are_recurring_stats_active_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='dlc_are_recurring_stats_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the recurring stats posts activated/deactivated.'),
        ),
    ]
