# Generated by Django 4.2.26 on 2025-11-15 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0081_remove_papsconfig_imp_modifier_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='bigbrotherconfig',
            name='token',
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_corp_brother_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Corp Brother module is enabled for this token.'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_daily_messages_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Daily Messages module is enabled for this token.'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_loa_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Leave of Absence module is enabled for this token.'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_pap_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the PAP module is enabled for this token.'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_reddit_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Reddit module is enabled for this token.'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='dlc_tickets_active',
            field=models.BooleanField(default=False, help_text='Read-only flag showing if the Tickets module is enabled for this token.'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='hostile_alliances',
            field=models.TextField(blank=True, default='', help_text="List of alliance IDs considered hostile, separated by ','", null=True),
        ),
        migrations.AlterField(
            model_name='processedcontract',
            name='contract_id',
            field=models.BigIntegerField(help_text='The Contract.contract_id that has been processed', primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='processedcontract',
            name='processed_at',
            field=models.DateTimeField(auto_now_add=True, help_text='When this contract was first processed'),
        ),
        migrations.AlterField(
            model_name='processedmail',
            name='mail_id',
            field=models.BigIntegerField(help_text='The MailMessage.id_key that has been processed', primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='processedmail',
            name='processed_at',
            field=models.DateTimeField(auto_now_add=True, help_text='When this mail was first processed'),
        ),
        migrations.AlterField(
            model_name='processedtransaction',
            name='entry_id',
            field=models.BigIntegerField(help_text='The WalletJournalEntry.entry_id that has been processed', primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='processedtransaction',
            name='processed_at',
            field=models.DateTimeField(auto_now_add=True, help_text='When this transaction was first processed'),
        ),
    ]
