# Generated by Django 4.2.23 on 2025-08-21 08:28

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('aa_bb', '0057_papsconfig_excluded_groups_papsconfig_excluded_users_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='papsconfig',
            name='excluded_groups_get_paps',
            field=models.BooleanField(default=False, editable=False, help_text='if user is in a group which prevent other groups from giving paps, do they get 1x group paps modifier?'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='excluded_users_paps',
            field=models.ManyToManyField(blank=True, help_text='List of user prevented from getting paps from groups', related_name='excluded_users_paps', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='excluded_users',
            field=models.ManyToManyField(blank=True, help_text='List of user prevented from getting all paps', related_name='excluded_user', to=settings.AUTH_USER_MODEL),
        ),
    ]
