# Generated by Django 4.2.20 on 2025-05-08 23:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0015_processedtransaction_sustransactionnote'),
    ]

    operations = [
        migrations.CreateModel(
            name='WarmProgress',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user_main', models.CharField(max_length=100, unique=True)),
                ('current', models.PositiveIntegerField()),
                ('total', models.PositiveIntegerField()),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
        ),
    ]
