# Generated by Django 4.2.23 on 2025-08-14 11:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0040_sovereigntymapcache_corporationinfocache_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='is_warmer_active',
            field=models.BooleanField(default=True, help_text='has the Cache warmer feature been activated/deactivated? (You need it if you have a gunicorn timeout set in your supervisor.conf, if you want to disable it, set the timeout to 0 first)'),
        ),
    ]
